==> libchipcard-0.8_1.tbz: include/chipcard/ctversion.h <==
/***************************************************************************
 $RCSfile: ctversion.h.in,v $
                             -------------------
    cvs         : $Id: ctversion.h.in,v 1.3 2003/02/10 13:11:40 aquamaniac Exp $
    begin       : Sun Dec 08 2002
    copyright   : (C) 2002 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/

/*
  Changes
 */

#ifndef CTVERSION_H
#define CTVERSION_H

// provide the version of this library
#define k_CHIPCARD_VERSION_MAJOR      0
#define k_CHIPCARD_VERSION_MINOR      8
#define k_CHIPCARD_VERSION_PATCHLEVEL 0
#define k_CHIPCARD_VERSION_BUILD      4
#define k_CHIPCARD_VERSION_STRING "0.8"
#define k_CHIPCARD_VERSION_COMPLETE_STRING "0.8.0.4"

#endif

==> libchipcard-0.9.1.tbz: include/chipcard/ctversion.h <==
/***************************************************************************
 $RCSfile: ctversion.h.in,v $
                             -------------------
    cvs         : $Id: ctversion.h.in,v 1.4 2003/03/31 01:49:44 aquamaniac Exp $
    begin       : Sun Dec 08 2002
    copyright   : (C) 2002 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/

/*
  Changes
 */

#ifndef CTVERSION_H
#define CTVERSION_H

// provide the version of this library
#define k_CHIPCARD_VERSION_MAJOR      0
#define k_CHIPCARD_VERSION_MINOR      9
#define k_CHIPCARD_VERSION_PATCHLEVEL 1
#define k_CHIPCARD_VERSION_BUILD      0
#define k_CHIPCARD_VERSION_TAG        STABLE
#define k_CHIPCARD_VERSION_STRING "0.9.1"
#define k_CHIPCARD_VERSION_COMPLETE_STRING "0.9.1.0 (STABLE)"
#endif /* CTVERSION_H */
